@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 """
-Copyright (C) 2008-2014 Wolfgang Rohdewald <wolfgang@rohdewald.de>
+Copyright (C) 2008-2016 Wolfgang Rohdewald <wolfgang@rohdewald.de>
 
 Kajongg is free software you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -27,11 +27,10 @@ from sys import _getframe
 
 # util must not import twisted or we need to change kajongg.py
 
-from common import Internal, Debug, unicode, isPython3, ENGLISHDICT  # pylint: disable=redefined-builtin
-from common import unicodeString, unicodeStringArgs, nativeString
+from common import Internal, Debug # pylint: disable=redefined-builtin
 from qt import Qt, QEvent
-from util import elapsedSince, traceback, gitHead
-from kde import i18n, i18nc
+from util import elapsedSince, traceback, gitHead, callers
+from mi18n import i18n
 from dialogs import Sorry, Information, NoPrompt
 
 
@@ -74,6 +73,10 @@ Fmt.formatter = Fmt()
 
 def id4(obj):
     """object id for debug messages"""
+    if obj is None:
+        return 'NONE'
+    if hasattr(obj, 'uid'):
+        return obj.uid
     return '.' if Debug.neutral else Fmt.num_encode(id(obj))
 
 def fmt(text, **kwargs):
@@ -114,7 +117,7 @@ def translateServerMessage(msg):
     string is always english. Here we unpack and translate it into the
     client language."""
     if msg.find(SERVERMARK) >= 0:
-        return m18n(*tuple(msg.split(SERVERMARK)[1:-1]))
+        return i18n(*tuple(msg.split(SERVERMARK)[1:-1]))
     return msg
 
 
@@ -124,18 +127,17 @@ def dbgIndent(this, parent):
         return ''
     else:
         pIndent = parent.indent if parent else 0
-        return (u' │ ' * (pIndent)) + u' ├' + u'─' * (this.indent - pIndent - 1)
+        return (' │ ' * (pIndent)) + ' ├' + '─' * (this.indent - pIndent - 1)
 
 
 def __logUnicodeMessage(prio, msg):
-    """if we can encode the unicode msg to ascii, do so.
-    Otherwise convert the unicode object into an utf-8 encoded
+    """if we can encode the str msg to ascii, do so.
+    Otherwise convert the str object into an utf-8 encoded
     str object.
-    The logger module would log the unicode object with the
+    The logger module would log the str object with the
     marker feff at the beginning of every message, we do not want that."""
     msg = msg.encode(getpreferredencoding(), 'ignore')[:4000]
-    if isPython3:
-        msg = msg.decode()
+    msg = msg.decode(getpreferredencoding())
     Internal.logger.log(prio, msg)
 
 
@@ -144,23 +146,25 @@ def __enrichMessage(msg, withGamePrefix=True):
     Add some optional prefixes to msg: S/C, process id, time, git commit.
 
     @param msg: The original message.
-    @type msg: C{unicode}
+    @type msg: C{str}
     @param withGamePrefix: If set, prepend the game prefix.
     @type withGamePrefix: C{Boolean}
-    @rtype: C{unicode}
+    @rtype: C{str}
     """
     result = msg  # set the default
     if withGamePrefix and Internal.logPrefix:
-        result = u'{prefix}{process}: {msg}'.format(
+        result = '{prefix}{process}: {msg}'.format(
             prefix=Internal.logPrefix,
             process=os.getpid() if Debug.process else '',
             msg=msg)
     if Debug.time:
-        result = u'{:08.4f} {}'.format(elapsedSince(Debug.time), result)
+        result = '{:08.4f} {}'.format(elapsedSince(Debug.time), result)
     if Debug.git:
         head = gitHead()
         if head not in ('current', None):
-            result = u'git:{}/p{} {}'.format(head, '3' if isPython3 else '2', result)
+            result = 'git:{}/p3 {}'.format(head, result)
+    if int(Debug.callers):
+        result = '  ' + result
     return result
 
 
@@ -171,21 +175,23 @@ def __exceptionToString(exception):
     @param exception: The exception to be logged.
     @type exception: C{Exception}
 
-    @rtype: C{unicode}
+    @rtype: C{str}
     """
     parts = []
     for arg in exception.args:
         if hasattr(arg, 'strerror'):
-            # when using pykde4, this is already translated at this point
+            # when using py kde 4, this is already translated at this point
             # but I do not know what it does differently with gettext and if
             # I can do the same with the python gettext module
             parts.append(
-                u'[Errno {}] {}'.format(arg.errno, m18n(arg.strerror)))
+                '[Errno {}] {}'.format(arg.errno, i18n(arg.strerror)))
         elif arg is None:
             pass
         else:
-            parts.append(unicode(arg))
-    return u' '.join(parts)
+            parts.append(str(arg))
+    if hasattr(exception, 'filename'):
+        parts.append(exception.filename)
+    return ' '.join(parts)
 
 
 def logMessage(msg, prio, showDialog, showStack=False, withGamePrefix=True):
@@ -193,7 +199,7 @@ def logMessage(msg, prio, showDialog, showStack=False, withGamePrefix=True):
     # pylint: disable=R0912
     if isinstance(msg, Exception):
         msg = __exceptionToString(msg)
-    msg = unicodeString(msg)
+    msg = str(msg)
     msg = translateServerMessage(msg)
     __logUnicodeMessage(prio, __enrichMessage(msg, withGamePrefix))
     if showStack:
@@ -204,11 +210,13 @@ def logMessage(msg, prio, showDialog, showStack=False, withGamePrefix=True):
         for line in traceback.format_stack()[lower:-3]:
             if 'logException' not in line:
                 __logUnicodeMessage(prio, '  ' + line.strip())
+    if int(Debug.callers):
+        __logUnicodeMessage(prio, callers(int(Debug.callers)))
     if showDialog and not Internal.isServer:
         if prio == logging.INFO:
             return Information(msg)
         else:
-            return Sorry(msg)
+            return Sorry(msg, always=True)
     return NoPrompt(msg)
 
 
@@ -236,88 +244,25 @@ def logWarning(msg, withGamePrefix=True):
     return logMessage(msg, logging.WARNING, True, withGamePrefix=withGamePrefix)
 
 
-def logException(exception, withGamePrefix=True):
+def logException(exception: str, withGamePrefix=True):
     """logs error message and re-raises exception"""
     logError(exception, withGamePrefix=withGamePrefix)
-    raise Exception(nativeString(exception))
-
-
-def m18n(englishText, *args):
-    """
-    Wrapper around i18n.
-
-    @param englishText : The text template.
-    @type englishText: C{str} (utf-8)  or C{unicode}.
-
-    @param args : Arguments for the text template.
-    @type args: A list or tuple of strings.
-
-    @return: The translated text with args inserted.
-    @rtype: C{unicode}.
-
-    Since when do args have to be unicode? utf-8
-    encoded fails.
-    """
-    result = unicodeString(
-        i18n(
-            nativeString(
-                englishText),
-            *unicodeStringArgs(args)))
-    if not args:
-        ENGLISHDICT[result] = unicodeString(englishText)
-    return result
-
-
-def m18nc(context, englishText, *args):
-    """
-    Wrapper around i18n. i18n only accepts and returns
-    native strings.
-
-    @param context: The context for this string.
-    @type context: C{str}
-    @param englishText : The text template.
-    @type englishText: C{str} (utf-8) or C{unicode}.
-
-    @param args : Arguments for the text template.
-    @type args: A list or tuple of strings.
-
-    @return: The translated text with args inserted.
-    @rtype: C{unicode}.
-    """
-    result = unicodeString(
-        i18nc(
-            context,
-            nativeString(englishText),
-            *unicodeStringArgs(args)))
-    if not args:
-        ENGLISHDICT[result] = unicodeString(englishText)
-    return result
-
-
-def m18nE(englishText):
-    """use this if you want to get the english text right now but still have the string translated"""
-    return unicodeString(englishText)
-
-
-def m18ncE(dummyContext, englishText):
-    """use this if you want to get the english text right now but still have the string translated"""
-    return unicodeString(englishText)
+    raise Exception(exception)
 
 
 class EventData(str):
 
     """used for generating a nice string"""
     events = {y: x for x, y in QEvent.__dict__.items() if isinstance(y, int)}
-    # add some old events which still arrive but are not supported by PyQt4
-    events[15] = 'Create'
-    events[16] = 'Destroy'
-    events[20] = 'Quit'
-    events[22] = 'ThreadChange'
-    events[67] = 'ChildInsertedRequest'
-    events[70] = 'ChildInserted'
-    events[152] = 'AcceptDropsChange'
-    events[154] = 'Windows:ZeroTimer'
-    events[178] = 'ContentsRectChange'
+    # those are not documented for qevent but appear in Qt5Core/qcoreevent.h
+    extra = {
+        15: 'Create',
+        16: 'Destroy',
+        20: 'Quit',
+        152: 'AcceptDropsChange',
+        154: 'Windows:ZeroTimer'
+    }
+    events.update(extra)
     keys = {y: x for x, y in Qt.__dict__.items() if isinstance(y, int)}
 
     def __new__(cls, receiver, event, prefix=None):
@@ -338,17 +283,17 @@ class EventData(str):
                     value += ':%s' % eventText
             if value:
                 value = '(%s)' % value
-            msg = u'%s%s->%s' % (name, value, receiver)
+            msg = '%s%s->%s' % (name, value, receiver)
             if hasattr(receiver, 'text'):
                 if receiver.__class__.__name__ != 'QAbstractSpinBox':
                     # accessing QAbstractSpinBox.text() gives a segfault
-                    msg += u'(%s)' % receiver.text()
+                    msg += '(%s)' % receiver.text()
             elif hasattr(receiver, 'objectName'):
-                msg += u'(%s)' % receiver.objectName()
+                msg += '(%s)' % receiver.objectName()
         else:
             msg = 'unknown event:%s' % event.type()
         if prefix:
-            msg = u': '.join([prefix, msg])
+            msg = ': '.join([prefix, msg])
         if 'all' in Debug.events or any(x in msg for x in Debug.events.split(':')):
             logDebug(msg)
         return msg
