@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-"""Copyright (C) 2013-2014 Wolfgang Rohdewald <wolfgang@rohdewald.de>
+"""Copyright (C) 2013-2016 Wolfgang Rohdewald <wolfgang@rohdewald.de>
 
 Kajongg is free software you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -27,7 +27,7 @@ from tile import Tile
 from meld import Meld, MeldList
 
 
-class Permutations(object):
+class Permutations:
 
     """creates permutations for building melds out of single tiles.
     NEVER returns Kongs!"""
