@@ -1,8 +1,7 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
 """
-Copyright (C) 2009-2014 Wolfgang Rohdewald <wolfgang@rohdewald.de>
+Copyright (C) 2009-2016 Wolfgang Rohdewald <wolfgang@rohdewald.de>
 
 Kajongg is free software you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -32,12 +31,13 @@ from itertools import chain
 
 from twisted.spread import pb
 
-from common import Debug, Internal
+from common import Debug, Internal, StrMixin
 from wind import Wind
 from tilesource import TileSource
 from util import Duration
 from message import Message, ChatMessage
-from log import logDebug, logError, m18nE, m18n, m18ncE
+from log import logDebug, logError
+from mi18n import i18nE, i18n, i18ncE
 from deferredutil import DeferredBlock
 from tile import Tile, TileList, elements
 from meld import Meld, MeldList
@@ -87,7 +87,7 @@ class ServerGame(PlayingGame):
         PlayingGame.initHand(self)
 
 
-class ServerTable(Table):
+class ServerTable(Table, StrMixin):
 
     """a table on the game server"""
     # pylint: disable=too-many-arguments
@@ -113,7 +113,7 @@ class ServerTable(Table):
         self.client = None
         server.tables[self.tableid] = self
         if Debug.table:
-            logDebug(u'new table %s' % self)
+            logDebug('new table %s' % self)
 
     def hasName(self, name):
         """returns True if one of the players in the game is named 'name'"""
@@ -133,27 +133,25 @@ class ServerTable(Table):
                 (x.wind.char, x.balance) for x in game.players)
         else:
             endValues = None
-        if withFullRuleset:
-            ruleset = self.ruleset.toList()
-        else:
-            ruleset = self.ruleset.hash
-        return list(
-            [self.tableid, ruleset, game.gameid if game else None, self.suspendedAt, self.running,
-             self.playOpen, self.autoPlay, self.wantedGame, names, online, endValues])
+        return list([
+            self.tableid,
+            self.ruleset.toList() if withFullRuleset else self.ruleset.hash,
+            game.gameid if game else None, self.suspendedAt, self.running,
+            self.playOpen, self.autoPlay, self.wantedGame, names, online, endValues])
 
     def maxSeats(self):
         """for a new game: 4. For a suspended game: The
         number of humans before suspending"""
         result = 4
         if self.suspendedAt:
-            result -= sum(x.name.startswith(u'Robot ')
+            result -= sum(x.name.startswith('Robot ')
                           for x in self.game.players)
         return result
 
     def sendChatMessage(self, chatLine):
         """sends a chat messages to all clients"""
         if Debug.chat:
-            logDebug(u'server sends chat msg %s' % chatLine)
+            logDebug('server sends chat msg %s' % chatLine)
         if self.suspendedAt and self.game:
             chatters = []
             for player in self.game.players:
@@ -167,14 +165,14 @@ class ServerTable(Table):
     def addUser(self, user):
         """add user to this table"""
         if user.name in list(x.name for x in self.users):
-            raise srvError(pb.Error, m18nE('You already joined this table'))
+            raise srvError(pb.Error, i18nE('You already joined this table'))
         if len(self.users) == self.maxSeats():
-            raise srvError(pb.Error, m18nE('All seats are already taken'))
+            raise srvError(pb.Error, i18nE('All seats are already taken'))
         self.users.append(user)
         if Debug.table:
-            logDebug(u'%s seated on table %s' % (user.name, self))
+            logDebug('%s seated on table %s' % (user.name, self))
         self.sendChatMessage(ChatMessage(self.tableid, user.name,
-                                         m18nE('takes a seat'), isStatusMessage=True))
+                                         i18nE('takes a seat'), isStatusMessage=True))
 
     def delUser(self, user):
         """remove user from this table"""
@@ -182,37 +180,37 @@ class ServerTable(Table):
             self.running = False
             self.users.remove(user)
             self.sendChatMessage(ChatMessage(self.tableid, user.name,
-                                             m18nE('leaves the table'), isStatusMessage=True))
+                                             i18nE('leaves the table'), isStatusMessage=True))
             if user is self.owner:
                 # silently pass ownership
                 if self.users:
                     self.owner = self.users[0]
                     if Debug.table:
-                        logDebug(u'%s leaves table %d, %s is the new owner' % (
+                        logDebug('%s leaves table %d, %s is the new owner' % (
                             user.name, self.tableid, self.owner))
                 else:
                     if Debug.table:
-                        logDebug(u'%s leaves table %d, table is now empty' % (
+                        logDebug('%s leaves table %d, table is now empty' % (
                             user.name, self.tableid))
             else:
                 if Debug.table:
-                    logDebug(u'%s leaves table %d, %s stays owner' % (
+                    logDebug('%s leaves table %d, %s stays owner' % (
                         user.name, self.tableid, self.owner))
 
-    def __unicode__(self):
+    def __str__(self):
         """for debugging output"""
         if self.users:
-            onlineNames = list(x.name + (u'(Owner)' if self.owner and x == self.owner.name else u'')
+            onlineNames = list(x.name + ('(Owner)' if self.owner and x == self.owner.name else '')
                                for x in self.users)
         else:
             onlineNames = list(['no users yet'])
-        offlineString = u''
+        offlineString = ''
         if self.game:
             offlineNames = list(x.name for x in self.game.players if x.name not in onlineNames
-                                and not x.name.startswith(u'Robot'))
+                                and not x.name.startswith('Robot'))
             if offlineNames:
-                offlineString = u' offline:' + u','.join(offlineNames)
-        return u'%d(%s%s)' % (self.tableid, u','.join(onlineNames), offlineString)
+                offlineString = ' offline:' + ','.join(offlineNames)
+        return '%d(%s%s)' % (self.tableid, ','.join(onlineNames), offlineString)
 
     def calcGameId(self):
         """based upon the max gameids we got from the clients, propose
@@ -229,13 +227,13 @@ class ServerTable(Table):
         # the server and all databases save the english name but we
         # want to make sure a translation exists for the client GUI
         robotNames = [
-            m18ncE(
+            i18ncE(
                 'kajongg, name of robot player, to be translated',
-                u'Robot 1'),
-            m18ncE(
+                'Robot 1'),
+            i18ncE(
                 'kajongg, name of robot player, to be translated',
-                u'Robot 2'),
-            m18ncE('kajongg, name of robot player, to be translated', u'Robot 3')]
+                'Robot 2'),
+            i18ncE('kajongg, name of robot player, to be translated', 'Robot 3')]
         while len(names) < 4:
             names.append(robotNames[3 - len(names)])
         names = list(tuple([Wind.all4[idx], name])
@@ -288,7 +286,7 @@ class ServerTable(Table):
         """the table initiator told us he wants to start the game"""
         if len(self.users) < self.maxSeats() and self.owner != user:
             raise srvError(pb.Error,
-                           m18nE(
+                           i18nE(
                                'Only the initiator %1 can start this game, you are %2'),
                            self.owner.name, user.name)
         if self.suspendedAt:
@@ -352,16 +350,16 @@ class ServerTable(Table):
                 if Debug.table:
                     if not userRequests:
                         logDebug(
-                            u'Server.startGame: found no request for user %s' %
+                            'Server.startGame: found no request for user %s' %
                             user.name)
                     else:
                         logDebug(
-                            u'Server.startGame: %s said NoGameStart' %
+                            'Server.startGame: %s said NoGameStart' %
                             user.name)
                 self.game = None
                 return
         if Debug.table:
-            logDebug(u'Game starts on table %s' % self)
+            logDebug('Game starts on table %s' % self)
         elementIter = iter(elements.all(self.game.ruleset))
         wallSize = len(self.game.wall.tiles)
         self.game.wall.tiles = []
@@ -384,7 +382,7 @@ class ServerTable(Table):
         if foreigners:
             if Debug.table:
                 logDebug(
-                    u'make running table %s invisible for %s' %
+                    'make running table %s invisible for %s' %
                     (self, ','.join(str(x) for x in foreigners)))
             for srvUser in foreigners:
                 self.server.callRemote(
@@ -408,7 +406,7 @@ class ServerTable(Table):
                 # send it to other human players:
                 others = [x for x in humanPlayers if x != player]
                 if Debug.sound:
-                    logDebug(u'telling other human players that %s has voiceId %s' % (
+                    logDebug('telling other human players that %s has voiceId %s' % (
                         player.name, remote.voiceId))
                 block.tell(
                     player,
@@ -432,7 +430,7 @@ class ServerTable(Table):
                 voiceFor.voice = Voice(voiceId)
                 if Debug.sound:
                     logDebug(
-                        u'client %s wants voice data %s for %s' %
+                        'client %s wants voice data %s for %s' %
                         (request.user.name, request.args[0], voiceFor))
                 voiceDataRequests.append((request.user, voiceFor))
                 if not voiceFor.voice.oggFiles():
@@ -455,7 +453,7 @@ class ServerTable(Table):
             if content:
                 if Debug.sound:
                     logDebug(
-                        u'server got voice data %s for %s from client' %
+                        'server got voice data %s for %s from client' %
                         (voiceFor.voice, voiceFor.name))
                 block.tell(
                     voiceFor,
@@ -464,7 +462,7 @@ class ServerTable(Table):
                     md5sum=voice.md5sum,
                     source=content)
             elif Debug.sound:
-                logDebug(u'server got empty voice data %s for %s from client' % (
+                logDebug('server got empty voice data %s for %s from client' % (
                     voice, voiceFor.name))
         block.callback(self.assignVoices)
 
@@ -519,7 +517,7 @@ class ServerTable(Table):
         tile = Tile(msg.args[0])
         if tile not in player.concealedTiles:
             self.abort(
-                u'player %s discarded %s but does not have it' %
+                'player %s discarded %s but does not have it' %
                 (player, tile))
             return
         dangerousText = self.game.dangerousFor(player, tile)
@@ -537,7 +535,7 @@ class ServerTable(Table):
         if violates:
             if Debug.originalCall:
                 tile = Tile(msg.args[0])
-                logDebug(u'%s just violated OC with %s' % (player, tile))
+                logDebug('%s just violated OC with %s' % (player, tile))
             player.mayWin = False
             block.tellAll(player, Message.ViolatesOriginalCall)
         block.callback(self._clientDiscarded3, msg, dangerousText, mustPlayDangerous)
@@ -560,7 +558,7 @@ class ServerTable(Table):
             if mustPlayDangerous and not player.lastSource.isDiscarded:
                 if Debug.dangerousGame:
                     tile = Tile(msg.args[0])
-                    logDebug(u'%s claims no choice. Discarded %s, keeping %s. %s' %
+                    logDebug('%s claims no choice. Discarded %s, keeping %s. %s' %
                              (player, tile, ''.join(player.concealedTiles), ' / '.join(dangerousText)))
                 player.claimedNoChoice = True
                 block.tellAll(
@@ -571,7 +569,7 @@ class ServerTable(Table):
                 player.playedDangerous = True
                 if Debug.dangerousGame:
                     tile = Tile(msg.args[0])
-                    logDebug(u'%s played dangerous. Discarded %s, keeping %s. %s' %
+                    logDebug('%s played dangerous. Discarded %s, keeping %s. %s' %
                              (player, tile, ''.join(player.concealedTiles), ' / '.join(dangerousText)))
                 block.tellAll(
                     player,
@@ -588,7 +586,7 @@ class ServerTable(Table):
         and then treat the implicit discard"""
         msg.player.originalCall = True
         if Debug.originalCall:
-            logDebug(u'server.clientMadeOriginalCall: %s' % msg.player)
+            logDebug('server.clientMadeOriginalCall: %s' % msg.player)
         block = DeferredBlock(self)
         block.tellAll(msg.player, Message.OriginalCall)
         block.callback(self._askForClaims, msg)
@@ -649,8 +647,8 @@ class ServerTable(Table):
         for block in DeferredBlock.blocks:
             if block.table == self:
                 logError(
-                    u'request left from previous hand: %s' %
-                    block.outstandingUnicode())
+                    'request left from previous hand: %s' %
+                    block.outstandingStr())
         token = self.game.handId.prompt(
             withAI=False)  # we need to send the old token until the
                                    # clients started the new hand
@@ -659,11 +657,11 @@ class ServerTable(Table):
             self.server.removeTable(
                 self,
                 'gameOver',
-                m18nE('Game <numid>%1</numid> is over!'),
+                i18nE('Game <numid>%1</numid> is over!'),
                 self.game.seed)
             if Debug.process and os.name != 'nt':
                 logDebug(
-                    u'MEM:%s' %
+                    'MEM:%s' %
                     resource.getrusage(resource.RUSAGE_SELF).ru_maxrss)
             return
         self.game.sortPlayers()
@@ -688,11 +686,11 @@ class ServerTable(Table):
         hasTiles = hasTiles.without(lastDiscard)
         meld = Meld(meldTiles)
         if len(meld) != 4 and not (meld.isPair or meld.isPungKong or meld.isChow):
-            msg = m18nE('%1 wrongly said %2 for meld %3')
+            msg = i18nE('%1 wrongly said %2 for meld %3')
             self.abort(msg, player.name, claim.name, str(meld))
             return
         if not player.hasConcealedTiles(hasTiles):
-            msg = m18nE(
+            msg = i18nE(
                 '%1 wrongly said %2: claims to have concealed tiles %3 but only has %4')
             self.abort(
                 msg,
@@ -715,7 +713,7 @@ class ServerTable(Table):
                 and discardingPlayer.playedDangerous):
             player.usedDangerousFrom = discardingPlayer
             if Debug.dangerousGame:
-                logDebug(u'%s claims dangerous tile %s discarded by %s' %
+                logDebug('%s claims dangerous tile %s discarded by %s' %
                          (player, lastDiscard, discardingPlayer))
             block.tellAll(
                 player,
@@ -731,15 +729,15 @@ class ServerTable(Table):
         """player declares a Kong, meldTiles is a list"""
         kongMeld = Meld(meldTiles)
         if not player.hasConcealedTiles(kongMeld) and kongMeld[0].exposed.pung not in player.exposedMelds:
-            msg = m18nE('declareKong:%1 wrongly said Kong for meld %2')
+            msg = i18nE('declareKong:%1 wrongly said Kong for meld %2')
             args = (player.name, str(kongMeld))
-            logDebug(m18n(msg, *args))
+            logDebug(i18n(msg, *args))
             logDebug(
-                u'declareKong:concealedTiles:%s' %
+                'declareKong:concealedTiles:%s' %
                 ''.join(player.concealedTiles))
-            logDebug(u'declareKong:concealedMelds:%s' %
+            logDebug('declareKong:concealedMelds:%s' %
                      ' '.join(str(x) for x in player.concealedMelds))
-            logDebug(u'declareKong:exposedMelds:%s' %
+            logDebug('declareKong:exposedMelds:%s' %
                      ' '.join(str(x) for x in player.exposedMelds))
             self.abort(msg, *args)
             return
@@ -752,7 +750,7 @@ class ServerTable(Table):
 
     def claimMahJongg(self, msg):
         """a player claims mah jongg. Check this and
-        if correct, tell all. Otherwise abort game,  kajongg client is faulty"""
+        if correct, tell all. Otherwise abort game, kajongg client is faulty"""
         if not self.running:
             return
         player = msg.player
@@ -779,7 +777,7 @@ class ServerTable(Table):
             player.lastTile,
             lastMeld)
         if not player.hand.won:
-            msg = m18nE('%1 claiming MahJongg: This is not a winning hand: %2')
+            msg = i18nE('%1 claiming MahJongg: This is not a winning hand: %2')
             self.abort(msg, player.name, player.hand.string)
             return
         block = DeferredBlock(self)
@@ -790,7 +788,7 @@ class ServerTable(Table):
                 and discardingPlayer.playedDangerous):
             player.usedDangerousFrom = discardingPlayer
             if Debug.dangerousGame:
-                logDebug(u'%s wins with dangerous tile %s from %s' %
+                logDebug('%s wins with dangerous tile %s from %s' %
                          (player, self.game.lastDiscard, discardingPlayer))
             block.tellAll(
                 player,
@@ -866,7 +864,7 @@ class ServerTable(Table):
         if not answers:
             return
         for answer in answers:
-            msg = u'<-  %s' % answer
+            msg = '<-  %s' % answer
             if Debug.traffic:
                 logDebug(msg)
             with Duration(msg):
@@ -878,7 +876,7 @@ class ServerTable(Table):
         if Debug.stack:
             stck = traceback.extract_stack()
             if len(stck) > 30:
-                logDebug(u'stack size:%d' % len(stck))
+                logDebug('stack size:%d' % len(stck))
                 logDebug(stck)
         answers = self.processAnswers(requests)
         if not answers:
